@@ -33,15 +33,13 @@ if __name__ == '__main__':
 
     # scan all ips
     print('scan ports for found IPs...')
-    pool = ThreadPool(processes=len(ips))
+    procs_num = max(len(ips), 10)
+    pool = ThreadPool(processes=procs_num)
     start_t = time()
-    procs = {ip: pool.apply_async(scan_ports, (ip, )) for ip in ips}
+    procs = {ip: pool.apply_async(scan_ports, (ip, True)) for ip in ips}
     ip_ports = {ip:proc.get() for ip,proc in procs.items()}
     end_t = time()
 
 
-    for i, ip in enumerate(ip_ports):
-        ports = ', '.join([str(p) for p in ip_ports[ip]])
-        print(f'{i+1}:\t {ip}\t => {ports}')
 
     print(f'scanned in {int(end_t-start_t)}s')
